==> vs.event-0.1.2.tar.gz: vs.event-0.1.2/vs/event/browser/vs-event.js <==
var $j = jQuery.noConflict();

function wholeDayHandler(e) {
    if (e.target.checked) 
        $j('.vs-calendarwidget-time').hide();
    else 
        $j('.vs-calendarwidget-time').show();
}

function useEndDateHandler(e) {
    if (e.target.checked) 
        $j('#archetypes-fieldname-endDate').show();
    else 
        $j('#archetypes-fieldname-endDate').hide();
}

$j(document).ready(function() {
    $j('#wholeDay').bind('change', wholeDayHandler);
    $j('#useEndDate').bind('change', useEndDateHandler);

    if (! $j('#useEndDate').attr('checked')) {
        $j('#archetypes-fieldname-endDate').hide();
    }


    // DatePicker stuff

    var UIDateFormat = 'yy/mm/dd';
    var BackendDateFormat = '%Y/%m/%d';
    // PLONE_LANGUAGE will be defined in vs_calendarwidget.pt
    try {
        language = PLONE_LANGUAGE;
    } catch(e) {language ='en';};
    
    if (language == 'de') {
        jQuery(function($){
                UIDateFormat = 'dd.mm.yy';
                BackendDateFormat = '%d.%m.%Y';
                
                $.datepicker.regional['de'] = {clearText: 'lschen', clearStatus: 'aktuelles Datum lschen',
                        closeText: 'schlieen', closeStatus: 'ohne nderungen schlieen',
                        prevText: '&#x3c;zurck', prevStatus: 'letzten Monat zeigen',
                        nextText: 'Vor&#x3e;', nextStatus: 'nchsten Monat zeigen',
                        currentText: 'heute', currentStatus: '',
                        monthNames: ['Januar','Februar','M&auml;rz','April','Mai','Juni',
                        'Juli','August','September','Oktober','November','Dezember'],
                        monthNamesShort: ['Jan','Feb','Mr','Apr','Mai','Jun',
                        'Jul','Aug','Sep','Okt','Nov','Dez'],
                        monthStatus: 'anderen Monat anzeigen', yearStatus: 'anderes Jahr anzeigen',
                        weekHeader: 'Wo', weekStatus: 'Woche des Monats',
                        dayNames: ['Sonntag','Montag','Dienstag','Mittwoch','Donnerstag','Freitag','Samstag'],
                        dayNamesShort: ['So','Mo','Di','Mi','Do','Fr','Sa'],
                        dayNamesMin: ['So','Mo','Di','Mi','Do','Fr','Sa'],
                        dayStatus: 'Setze DD als ersten Wochentag', dateStatus: 'Whle D, M d',
                        dateFormat: 'dd.mm.yy', firstDay: 1, 
                        initStatus: 'Whle ein Datum', isRTL: false};
                $.datepicker.setDefaults($.datepicker.regional['de']);
        });
    }

    $j('.calendarInput').datepicker({dateFormat : UIDateFormat,
                                     numberOfMonths : 1,
                                     showButtonPanel : true,
                                     });

    $j('.calendarInputDateFormat').each(function(f) {
            this.value = BackendDateFormat;
    });

})

==> vs.event-0.2.0.tar.gz: vs.event-0.2.0/vs/event/browser/vs-event.js <==
var $j = jQuery.noConflict();

function wholeDayHandler(e) {
    if (e.target.checked) 
        $j('.vs-calendarwidget-time').fadeOut();
    else 
        $j('.vs-calendarwidget-time').fadeIn();
}

function useEndDateHandler(e) {
    if (e.target.checked) 
        $j('#archetypes-fieldname-endDate').fadeIn();
    else 
        $j('#archetypes-fieldname-endDate').fadeOut();
}

$j(document).ready(function() {
    $j('#wholeDay').bind('change', wholeDayHandler);
    $j('#useEndDate').bind('change', useEndDateHandler);

    if (! $j('#useEndDate').attr('checked')) {
        $j('#archetypes-fieldname-endDate').fadeOut();
    }

    // DatePicker stuff

    var UIDateFormat = 'yy/mm/dd';
    var BackendDateFormat = '%Y/%m/%d';
    // PLONE_LANGUAGE will be defined in vs_calendarwidget.pt
    try {
        language = PLONE_LANGUAGE;
    } catch(e) {language ='en';};
    
    if (language == 'de') {
        jQuery(function($){
                UIDateFormat = 'dd.mm.yy';
                BackendDateFormat = '%d.%m.%Y';
                
                $.datepicker.regional['de'] = {clearText: 'l&ouml;schen', clearStatus: 'aktuelles Datum l&ouml;schen',
                        closeText: 'schlie&szlig;en', closeStatus: 'ohne &Auml;nderungen schlie&szlig;en',
                        prevText: '< zur&uuml;ck', prevStatus: 'letzten Monat zeigen',
                        nextText: 'Vor >', nextStatus: 'n&auml;chsten Monat zeigen',
                        currentText: 'heute', currentStatus: '',
                        monthNames: ['Januar','Februar','M&auml;rz','April','Mai','Juni',
                        'Juli','August','September','Oktober','November','Dezember'],
                        monthNamesShort: ['Jan','Feb','M&auml;r','Apr','Mai','Jun',
                        'Jul','Aug','Sep','Okt','Nov','Dez'],
                        monthStatus: 'anderen Monat anzeigen', yearStatus: 'anderes Jahr anzeigen',
                        weekHeader: 'Wo', weekStatus: 'Woche des Monats',
                        dayNames: ['Sonntag','Montag','Dienstag','Mittwoch','Donnerstag','Freitag','Samstag'],
                        dayNamesShort: ['So','Mo','Di','Mi','Do','Fr','Sa'],
                        dayNamesMin: ['So','Mo','Di','Mi','Do','Fr','Sa'],
                        dayStatus: 'Setze DD als ersten Wochentag', dateStatus: 'W&auml;hle D, M d',
                        dateFormat: 'dd.mm.yy', firstDay: 1, 
                        initStatus: 'W&auml;hle ein Datum', isRTL: false};
                $.datepicker.setDefaults($.datepicker.regional['de']);
        });
    }

    $j('.calendarInput').datepicker({dateFormat : UIDateFormat,
                                     numberOfMonths : 1,
                                     showButtonPanel : true,
                                     });

    $j('.calendarInputDateFormat').each(function(f) {
            this.value = BackendDateFormat;
    });

})
